@@ -489,9 +489,9 @@ class DataTransformerForm(BaseInlineFormSet):
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
-        if hasattr(form.instance,'is_root_node') and form.instance.is_root_node():
+        if hasattr(form.instance,'_is_saved') and form.instance._is_saved():
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
-                                                                 fk_name='parent', form=DataTransform, extra=0
+                                                                 fk_name='parent', form=DataTransform, extra=1
                                                                  )
             form.nested_data_transformer_form = dataTransformerInlineFormset(
                 data=form.data if form.is_bound else None,
